# hoangk7 

test by hoang

## Examples of How To Use
```

Creating Class Hoang
```python
from hoangk7 import Hoang
hoang = Hoang(12,2)
hoang.nhan()
print("-------")
hoang.info()
```

Check out: https://www.facebook.com/hoanglailaptrinh123